import assets from '../../../Assets/Sprites/**/*.yaml'
import { Sprite } from '../data/sprite'
import * as PIXI from 'pixi.js'

export const sprites: Record<string, Sprite> = {}

for (let [key, value] of Object.entries(assets)) {
  sprites[key] = new Sprite(value)
}

export class SpriteInstance {
  container: PIXI.Container

  constructor(ctor: string) {
    this.container = new PIXI.Container()
    let [spriteKey, animationKey, setKey, subsetKey, frameKey] = ctor.split('.')
    let frameIndex = Number(frameKey)
    let sprite = sprites[spriteKey]
    if (!sprite) {
      this.container.addChild(new PIXI.Text('missing sprite'))
      return
    }
    let animation = sprite.root.children[animationKey]
    let set = animation.children[setKey]
    let subset = set.children[subsetKey]
    //
    if (subset.frames) {
      let frame = subset.frames[frameIndex]
      let s = new PIXI.Sprite(frame.texture)
      s.x -= frame.originX
      s.y -= frame.originY
      this.container.addChild(s)
    }
  }
}